package com.yiqi.admin.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.app.domain.AppFeedback;
import com.yiqi.app.service.IAppFeedbackService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * APP意见反馈Controller
 *
 * @author ruoyi
 * @date 2023-11-08
 */
@Api(tags = "管理后台 - APP意见反馈")
@RestController
@RequestMapping(UrlConstants.managerApi + "/app/feedback")
public class AppFeedbackController extends BaseController {
    @Autowired
    private IAppFeedbackService appFeedbackService;

    /**
     * 查询APP意见反馈列表
     */
    @PreAuthorize("@ss.hasPermi('app:feedback:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询APP意见反馈列表")
    public TableDataInfo list(AppFeedback appFeedback) {
        startPage();
        List<AppFeedback> list = appFeedbackService.selectAppFeedbackList(appFeedback);
        return getDataTable(list);
    }

    /**
     * 导出APP意见反馈列表
     */
    @PreAuthorize("@ss.hasPermi('app:feedback:export')")
    @Log(title = "APP意见反馈", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出APP意见反馈列表")
    public void export(HttpServletResponse response, AppFeedback appFeedback) {
        List<AppFeedback> list = appFeedbackService.selectAppFeedbackList(appFeedback);
        ExcelUtil<AppFeedback> util = new ExcelUtil<AppFeedback>(AppFeedback. class);
        util.exportExcel(response, list, "APP意见反馈数据");
    }

    /**
     * 获取APP意见反馈详细信息
     */
    @PreAuthorize("@ss.hasPermi('app:feedback:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取APP意见反馈详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(appFeedbackService.selectAppFeedbackById(id));
    }

    /**
     * 新增APP意见反馈
     */
    @PreAuthorize("@ss.hasPermi('app:feedback:add')")
    @Log(title = "APP意见反馈", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增APP意见反馈")
    public AjaxResult add(@RequestBody AppFeedback appFeedback) {
        appFeedback.setCreateById(getUserId());
        appFeedback.setCreateBy(getUsername());
        return toAjax(appFeedbackService.insertAppFeedback(appFeedback));
    }

    /**
     * 回复APP意见反馈
     */
    @PreAuthorize("@ss.hasPermi('app:feedback:edit')")
    @Log(title = "APP意见反馈", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改APP意见反馈")
    public AjaxResult edit(@RequestBody AppFeedback appFeedback) {
        appFeedback.setUpdateById(getUserId());
        appFeedback.setUpdateBy(getUsername());
        return toAjax(appFeedbackService.updateAppFeedback(appFeedback));
    }

    /**
     * 删除APP意见反馈
     */
    @PreAuthorize("@ss.hasPermi('app:feedback:remove')")
    @Log(title = "APP意见反馈", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除APP意见反馈")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(appFeedbackService.deleteAppFeedbackByIds(ids));
    }

    /**
     * 修改APP意见反馈状态
     */
    @PreAuthorize("@ss.hasPermi('app:feedback:edit')")
    @Log(title = "APP意见反馈", businessType = BusinessType.UPDATE)
    @PostMapping(value = "updateStatus")
    @ApiOperation(value = "修改APP意见反馈状态")
    public AjaxResult updateAppFeedbackStatus(@RequestBody AppFeedback appFeedback) {
        return toAjax(appFeedbackService.updateAppFeedbackStatus(appFeedback));
    }
}
